/*
 * Copyright (c) 2002-2012, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.directory.business;

import fr.paris.lutece.portal.service.plugin.Plugin;

import java.util.List;


/**
 *
 * IDirectoryXslDAO
 *
 */
public interface IDirectoryXslDAO
{
    /**
     * Generates a new primary key
     *
     * @param plugin the plugin
     * @return The new primary key
     */
    int newPrimaryKey( Plugin plugin );

    /**
     * Insert a new record in the table.
     *
     * @param directoryXsl instance of the DirectoryXsl object to insert
     * @param plugin the plugin
     */
    void insert( DirectoryXsl directoryXsl, Plugin plugin );

    /**
     * Load the data of the DirectoryXsl  from the table
     *
     * @param nId The identifier of the xsl
     * @param plugin the plugin
     * @return the instance of the  DirectoryXsl
     */
    DirectoryXsl load( int nId, Plugin plugin );

    /**
     * Delete a record from the table
     *
     * @param nIdDirectoryXsl The identifier of the directory xsl
     * @param plugin the plugin
     */
    void delete( int nIdDirectoryXsl, Plugin plugin );

    /**
     * Update the directoryXsl in the table
     *
     * @param directoryXsl instance of the DirectoryXsl object to update
     * @param plugin the plugin
     */
    void store( DirectoryXsl directoryXsl, Plugin plugin );

    /**
     * Load the data of all the xsl and returns them in form of a list
     * @param filter the search filter
     * @param plugin the plugin
     * @return The List which contains the data of all the XSL
     */
    List<DirectoryXsl> selectList( DirectoryXslFilter filter, Plugin plugin );
}
